@@ -280,43 +280,67 @@ extract_head_content <- function(html_content) {
 #'
 #' This function creates various types of survey questions for use in a Surveydown survey.
 #'
-#' @param type Specifies the type of question. Possible values are "select", "mc",
-#'   "mc_multiple", "mc_buttons", "mc_multiple_buttons", "text", "textarea",
-#'   "numeric", "slider", "date", "daterange", and "matrix".
-#' @param id A unique identifier for the question, which will be used as the variable name in the resulting survey data.
-#' @param label Character string. The label for the UI element, which can be formatted with markdown.
-#' @param cols Integer. Number of columns for the textarea input. Defaults to 80.
-#' @param direction Character string. The direction for button groups ("horizontal" or "vertical"). Defaults to "horizontal".
-#' @param status Character string. The status for button groups. Defaults to "default".
-#' @param width Character string. The width of the UI element. Defaults to "100%".
-#' @param height Character string. The height of the textarea input. Defaults to "100px".
+#' @param type Specifies the type of question. Possible values are `"select"`,
+#' `"mc"`, `"mc_multiple"`, `"mc_buttons"`, `"mc_multiple_buttons"`, `"text"`,
+#' `"textarea"`, `"numeric"`, `"slider"`, `"slider_numeric"`, `"date"`,
+#' `"daterange"`, and `"matrix"`.
+#' @param id A unique identifier for the question, which will be used as the
+#' variable name in the resulting survey data.
+#' @param label Character string. The label for the UI element, which can be
+#' formatted with markdown.
+#' @param cols Integer. Number of columns for the `"textarea"` question type.
+#' Defaults to 80.
+#' @param direction Character string. The direction for button groups
+#' (`"horizontal"` or `"vertical"`). Defaults to `"horizontal"`.
+#' @param status Character string. The status for button groups.
+#' Defaults to `"default"`.
+#' @param width Character string. The width of the UI element.
+#' Defaults to `"100%"`.
+#' @param height Character string. The height of the input for the
+#' `"textarea"` question type. Defaults to `"100px"`.
 #' @param selected Value. The selected value(s) for certain input elements.
-#' @param label_select Character string. The label for the select input. Defaults to "Choose an option...".
-#' @param grid Logical. Whether to show a grid for slider input. Defaults to TRUE.
-#' @param individual Logical. Whether buttons in a group should be individually styled. Defaults to TRUE.
-#' @param justified Logical. Whether buttons in a group should fill the width of the parent div. Defaults to FALSE.
-#' @param force_edges Logical. Whether to force edges for slider input. Defaults to TRUE.
-#' @param option List. Options for the select, radio, checkbox, and slider inputs.
-#' @param placeholder Character string. Placeholder text for text and textarea inputs.
-#' @param resize Character string. Resize option for textarea input. Defaults to NULL.
-#' @param row List. Used for "matrix" type questions. Contains the row labels and their corresponding IDs.
-#'
+#' @param label_select Character string. The label for the select input.
+#' Defaults to `"Choose an option..."`.
+#' @param grid Logical. Whether to show a grid for slider input.
+#' Defaults to `TRUE`.
+#' @param individual Logical. Whether buttons in a group should be individually
+#'  styled. Defaults to `TRUE`.
+#' @param justified Logical. Whether buttons in a group should fill the width
+#' of the parent div. Defaults to `FALSE`.
+#' @param force_edges Logical. Whether to force edges for slider input.
+#' Defaults to `TRUE`.
+#' @param option Named vector for the `"select"`, `"radio"`, `"checkbox"`,
+#' and `"slider"` question types, or numeric vector for `"slider_numeric"`
+#' question type.
+#' @param placeholder Character string. Placeholder text for `"text"` and
+#' `"textarea"` question types.
+#' @param resize Character string. Resize option for textarea input.
+#' Defaults to `NULL`.
+#' @param row List. Used for `"matrix"` type questions. Contains the row labels
+#' and their corresponding IDs.
+#' @param default Numeric, length 1 (for a single sided slider), or 2 for a
+#' two sided (range based) slider. Values to be used as the starting default
+#' for the slider. Defaults to the median of values.
+#' @param ... Additional arguments, often specific to different input types.
+#' Examples include `pre`, `sep`, `step`, and `animate` for `"slider"` and
+#' `"slider_numeric"` question types, etc.
 #' @details
 #' The function supports various question types:
-#' - "select": A dropdown selection
-#' - "mc": Multiple choice (single selection)
-#' - "mc_multiple": Multiple choice (multiple selections allowed)
-#' - "mc_buttons": Multiple choice with button-style options (single selection)
-#' - "mc_multiple_buttons": Multiple choice with button-style options (multiple selections allowed)
-#' - "text": Single-line text input
-#' - "textarea": Multi-line text input
-#' - "numeric": Numeric input
-#' - "slider": Slider input
-#' - "date": Date input
-#' - "daterange": Date range input
-#' - "matrix": Matrix-style question with rows and columns
+#' - `"select"`: A dropdown selection
+#' - `"mc"`: Multiple choice (single selection)
+#' - `"mc_multiple"`: Multiple choice (multiple selections allowed)
+#' - `"mc_buttons"`: Multiple choice with button-style options (single selection)
+#' - `"mc_multiple_buttons"`: Multiple choice with button-style options (multiple selections allowed)
+#' - `"text"`: Single-line text question
+#' - `"textarea"`: Multi-line text question
+#' - `"numeric"`: Numeric question
+#' - `"slider"`: Slider question
+#' - `"slider_numeric"`: Extended numeric slider question
+#' - `"date"`: Date question
+#' - `"daterange"`: Date range question
+#' - `"matrix"`: Matrix-style question with rows and columns
 #'
-#' For "matrix" type questions, use the `row` parameter to define the rows of
+#' For `"matrix"` type questions, use the `row` parameter to define the rows of
 #' the matrix. Each element in the `row` list should have a name (used as the
 #' row ID) and a value (used as the row label).
 #'
@@ -368,13 +392,16 @@ sd_question <- function(
     option       = NULL,
     placeholder  = NULL,
     resize       = NULL,
-    row          = NULL
-) {
+    row          = NULL,
+    default      = NULL,
+    ...
+    ) {
 
   # Define valid question types
   valid_types <- c(
     "select", "mc", "mc_multiple", "mc_buttons", "mc_multiple_buttons",
-    "text", "textarea", "numeric", "slider", "date", "daterange", "matrix"
+    "text", "textarea", "numeric", "slider", "slider_numeric", "date",
+    "daterange", "matrix"
   )
 
   # Check if provided type is valid
@@ -412,15 +439,18 @@ sd_question <- function(
       label    = label,
       choices  = option,
       multiple = FALSE,
-      selected = FALSE
+      selected = FALSE,
+      ...
     )
+
   } else if (type == "mc") {
 
     output <- shiny::radioButtons(
       inputId  = id,
       label    = label,
       choices  = option,
-      selected = FALSE
+      selected = FALSE,
+      ...
     )
 
   } else if (type == "mc_multiple") {
@@ -429,7 +459,8 @@ sd_question <- function(
       inputId  = id,
       label    = label,
       choices  = option,
-      selected = FALSE
+      selected = FALSE,
+      ...
     )
 
   } else if (type == "mc_buttons") {
@@ -439,7 +470,8 @@ sd_question <- function(
       label     = label,
       choices   = list_name_md_to_html(option),
       direction = direction,
-      selected  = character(0)
+      selected  = character(0),
+      ...
     )
 
     output <- shiny::tagAppendChild(output, shiny::tags$script(htmltools::HTML(sprintf("
@@ -456,7 +488,8 @@ sd_question <- function(
       choices    = list_name_md_to_html(option),
       direction  = direction,
       individual = individual,
-      justified  = FALSE
+      justified  = FALSE,
+      ...
     )
 
     output <- shiny::tagAppendChild(output, shiny::tags$script(htmltools::HTML(sprintf("
@@ -464,13 +497,13 @@ sd_question <- function(
                 %s
             });
         ", id, js_interaction))))
-
   } else if (type == "text") {
 
     output <- shiny::textInput(
       inputId     = id,
       label       = label,
-      placeholder = option
+      placeholder = option,
+      ...
     )
 
   } else if (type == "textarea") {
@@ -483,7 +516,8 @@ sd_question <- function(
       value       = NULL,
       rows        = "6",
       placeholder = placeholder,
-      resize      = resize
+      resize      = resize,
+      ...
     )
 
   } else if (type == "numeric") {
@@ -491,36 +525,145 @@ sd_question <- function(
     output <- shiny::numericInput(
       inputId = id,
       label   = label,
-      value   = NULL
+      value   = NULL,
+      ...
     )
 
   } else if (type == "slider") {
+      # For text-based slider, we need to ensure labels are displayed correctly
 
-    slider_values <- make_slider_values(option)
-    if (!is.null(shiny::getDefaultReactiveDomain())) {
-      session <- shiny::getDefaultReactiveDomain()
-      session$userData[[paste0(id, "_values")]] <- slider_values
-    }
+      # First, understand option format:
+      # option = c("Label 1" = "value1", "Label 2" = "value2", ...)
 
-    output <- shinyWidgets::sliderTextInput(
-      inputId     = id,
-      label       = label,
-      choices     = names(slider_values),
-      selected    = selected,
-      force_edges = force_edges,
-      grid        = grid
-    )
+      # Extract display labels and values
+      display_labels <- names(option)
+      values <- unname(option)
 
-    js_convert <- sprintf("
-      $(document).on('change', '#%s', function() {
-        var valueMap = %s;
-        var currentValue = $(this).val();
-        Shiny.setInputValue('%s', valueMap[currentValue]);
+      # Value to display mapping (for finding the display label from a selected value)
+      value_to_label <- display_labels
+      names(value_to_label) <- values
+
+      # Create a choices vector that sliderTextInput will use
+      slider_choices <- display_labels
+
+      # Determine the selected display label based on the selected value
+      selected_label <- NULL
+      if (!is.null(selected) && selected != "") {
+          selected_label <- value_to_label[selected]
+      }
+
+      # If no valid selection, default to first choice
+      if (is.null(selected_label) || is.na(selected_label)) {
+          selected_label <- slider_choices[1]
+      }
+
+      # Store the mapping for later use in JavaScript
+      value_map <- option
+
+      if (!is.null(shiny::getDefaultReactiveDomain())) {
+          session <- shiny::getDefaultReactiveDomain()
+          session$userData[[paste0(id, "_values")]] <- value_map
+      }
+
+      # Create the slider with display labels
+      output <- shinyWidgets::sliderTextInput(
+          inputId     = id,
+          label       = label,
+          choices     = slider_choices,  # These are the display labels
+          selected    = selected_label,  # Must be a display label, not a value
+          force_edges = force_edges,
+          grid        = grid,
+          ...
+      )
+
+      # JavaScript to map the display label back to the stored value
+      js_convert <- sprintf("
+    $(document).on('change', '#%s', function() {
+      var valueMap = %s;
+      var currentLabel = $(this).val();
+
+      // Find the internal value that matches this display label
+      Shiny.setInputValue('%s', valueMap[currentLabel]);
+    });
+  ", id, jsonlite::toJSON(as.list(value_map)), id)
+
+      output <- shiny::tagAppendChild(
+          output,
+          shiny::tags$script(htmltools::HTML(js_convert))
+      )
+
+    } else if (type == "slider_numeric") {
+      # Handle numeric slider - supports BOTH single and range values
+      slider_values <- option
+
+      if (!is.null(shiny::getDefaultReactiveDomain())) {
+          session <- shiny::getDefaultReactiveDomain()
+          session$userData[[paste0(id, "_values")]] <- slider_values
+      }
+
+      if (is.null(default)) {
+          default <- stats::median(slider_values)
+      }
+
+      # Check if this is a range slider
+      is_range <- is.numeric(default) && length(default) > 1
+
+      # Create the slider
+      output <- shiny::sliderInput(
+          inputId = id,
+          label   = label,
+          min     = min(slider_values),
+          max     = max(slider_values),
+          value   = default,  # Can be single value or vector of length 2 for range
+          ...
+      )
+
+      # For range sliders, add a custom observer that manually creates a string value
+      if (is_range) {
+          # Add JavaScript to force a manual string representation of the range
+          js_range_handler <- sprintf("
+      $(document).on('slidechange', '#%s', function(event, ui) {
+        // Track interaction for progress
+        Shiny.setInputValue('%s_interacted', true, {priority: 'event'});
+
+        // Force a string representation for range sliders
+        if (ui.values) {
+          var rangeString = ui.values.join(', ');
+          Shiny.setInputValue('%s_manual_range', rangeString);
+        }
       });
-    ", id, jsonlite::toJSON(as.list(slider_values)), id)
+    ", id, id, id)
 
-    output <- shiny::tagAppendChild(output,
-                                    shiny::tags$script(htmltools::HTML(js_convert)))
+          output <- shiny::tagAppendChild(
+              output,
+              shiny::tags$script(htmltools::HTML(js_range_handler))
+          )
+
+          # Add an observer in the server to capture this string value
+          if (!is.null(shiny::getDefaultReactiveDomain())) {
+              shiny::observe({
+                  # Get the range string from our custom input
+                  range_string <- shiny::getDefaultReactiveDomain()$input[[paste0(id, "_manual_range")]]
+
+                  if (!is.null(range_string) && range_string != "") {
+                      # Store this directly using the main id
+                      sd_store_value(range_string, id)
+                  }
+              })
+          }
+      } else {
+          # For single sliders, just track interaction
+          js_single_handler <- sprintf("
+      $(document).on('slidechange', '#%s', function() {
+        Shiny.setInputValue('%s_interacted', true, {priority: 'event'});
+      });
+    ", id, id)
+
+          output <- shiny::tagAppendChild(
+              output,
+              shiny::tags$script(htmltools::HTML(js_single_handler))
+          )
+      }
 
   } else if (type == "date") {
 
@@ -536,7 +679,8 @@ sd_question <- function(
       language           = language,
       autoclose          = TRUE,
       datesdisabled      = NULL,
-      daysofweekdisabled = NULL
+      daysofweekdisabled = NULL,
+      ...
     )
 
     output <- date_interaction(output, id)
@@ -555,12 +699,14 @@ sd_question <- function(
       weekstart = 0,
       language  = language,
       separator = "-",
-      autoclose = TRUE
+      autoclose = TRUE,
+      ...
     )
 
     output <- date_interaction(output, id)
 
   } else if (type == "matrix") {
+
     header <- shiny::tags$tr(
       shiny::tags$th(""),
       lapply(names(option), function(opt) shiny::tags$th(opt))
@@ -576,7 +722,8 @@ sd_question <- function(
             id = full_id,
             label = NULL,
             option = option,
-            direction = "horizontal"
+            direction = "horizontal",
+            ...
           )
         )
       )
@@ -609,14 +756,6 @@ sd_question <- function(
   }
 }
 
-make_slider_values <- function(labels) {
-  values <- tolower(gsub("[^[:alnum:]]", "_", labels))
-  values <- gsub("_{2,}", "_", values)  # Replace multiple underscores with single
-  values <- gsub("^_|_$", "", values)   # Remove leading/trailing underscores
-  names(values) <- labels
-  return(values)
-}
-
 #' Create a Custom Question with a Shiny Widget
 #'
 #' @description
